# Generated by roxygen2: do not edit by hand

S3method(predict,ddesonn_model)
S3method(print,ddesonn_run_result)
export(DDESONN_activation_defaults)
export(DDESONN_artifacts_root)
export(DDESONN_dropout_defaults)
export(DDESONN_fit)
export(DDESONN_model)
export(DDESONN_optimizer_options)
export(DDESONN_plots_dir)
export(DDESONN_predict)
export(DDESONN_run)
export(DDESONN_training_defaults)
export(arctangent)
export(arctangent_derivative)
export(bent_identity)
export(bent_identity_derivative)
export(bent_relu)
export(bent_relu_derivative)
export(bent_sigmoid)
export(bent_sigmoid_derivative)
export(bent_swish)
export(bent_swish_derivative)
export(binary_activation)
export(binary_activation_derivative)
export(custom_activation)
export(custom_activation_derivative)
export(custom_bent_piecewise)
export(custom_bent_piecewise_derivative)
export(custom_binary_activation)
export(custom_binary_activation_derivative)
export(ddesonn_activation_defaults)
export(ddesonn_artifacts_root)
export(ddesonn_debug_state)
export(ddesonn_dropout_defaults)
export(ddesonn_fit)
export(ddesonn_model)
export(ddesonn_optimizer_options)
export(ddesonn_plots_dir)
export(ddesonn_predict)
export(ddesonn_run)
export(ddesonn_training_defaults)
export(elu)
export(elu_derivative)
export(gaussian)
export(gaussian_derivative)
export(gelu)
export(gelu_derivative)
export(hard_sigmoid)
export(hard_sigmoid_derivative)
export(identity)
export(identity_derivative)
export(inverse_linear_unit)
export(inverse_linear_unit_derivative)
export(isrlu)
export(isrlu_derivative)
export(leaky_bent)
export(leaky_bent_derivative)
export(leaky_relu)
export(leaky_relu_derivative)
export(leaky_selu)
export(leaky_selu_derivative)
export(maxout)
export(maxout_derivative)
export(mish)
export(mish_derivative)
export(parametric_bent_relu)
export(parametric_bent_relu_derivative)
export(prelu)
export(prelu_derivative)
export(relu)
export(relu_derivative)
export(selu)
export(selu_derivative)
export(sigmoid)
export(sigmoid_binary)
export(sigmoid_binary_derivative)
export(sigmoid_derivative)
export(sigmoid_sharp)
export(sigmoid_sharp_derivative)
export(sinusoid)
export(sinusoid_derivative)
export(softmax)
export(softmax_derivative)
export(softplus)
export(softplus_derivative)
export(swish)
export(swish_derivative)
export(tanh)
export(tanh_derivative)
export(tanh_relu_hybrid)
export(tanh_relu_hybrid_derivative)
importFrom(R6,R6Class)
importFrom(grDevices,dev.list)
importFrom(grDevices,dev.off)
importFrom(graphics,abline)
importFrom(graphics,grid)
importFrom(graphics,legend)
importFrom(stats,aggregate)
importFrom(stats,dist)
importFrom(stats,kmeans)
importFrom(stats,na.omit)
importFrom(stats,predict)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(utils,globalVariables)
importFrom(utils,head)
importFrom(utils,object.size)
importFrom(utils,str)
importFrom(utils,tail)
